Documentation
¶
Index ¶
- func Doctor(engine Engine, options OperationOptions) error
- func Down(engine Engine, options OperationOptions) error
- func Maneuver(engine Engine, options OperationOptions, maneuverName string) error
- func ModulesInit(engine Engine) error
- func ModulesStatus(engine Engine) error
- func ModulesSync(engine Engine) error
- func ModulesUpdate(engine Engine) error
- func Signal(engine Engine, options OperationOptions, arguments []string) error
- func Status(engine Engine, options OperationOptions) error
- func Tree(engine Engine) error
- func Up(engine Engine, options OperationOptions) error
- type Engine
- type OperationOptions
- type RuntimeNode
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Doctor ¶
func Doctor(engine Engine, options OperationOptions) error
Doctor validates topology and maneuver definitions.
func Down ¶
func Down(engine Engine, options OperationOptions) error
Down stops the runtime root and subordinates in reverse dependency order.
func Maneuver ¶
func Maneuver(engine Engine, options OperationOptions, maneuverName string) error
Maneuver executes a named maneuver on the runtime root node.
func ModulesInit ¶
ModulesInit runs git submodule init for the runtime root.
func ModulesStatus ¶
ModulesStatus runs git submodule status for the runtime root.
func ModulesSync ¶
ModulesSync runs git submodule sync for the runtime root.
func ModulesUpdate ¶
ModulesUpdate runs git submodule update for the runtime root.
func Signal ¶
func Signal(engine Engine, options OperationOptions, arguments []string) error
Signal routes an action to one subordinate or broadcasts to direct subordinates.
func Status ¶
func Status(engine Engine, options OperationOptions) error
Status reports runtime node statuses for current scope.
func Up ¶
func Up(engine Engine, options OperationOptions) error
Up starts the runtime root and subordinates in dependency order.
Types ¶
type Engine ¶
type Engine interface {
EnsureInitialized() error
NormalizeOptions(options OperationOptions) OperationOptions
Root() *RuntimeNode
NodesByID() map[string]*RuntimeNode
ResolveExecutionOrder(runtime *RuntimeNode, nodesByID map[string]*RuntimeNode) ([]*RuntimeNode, error)
BuildEffectiveEnvironments(runtime *RuntimeNode, environmentName string) (map[string]domain.EnvironmentDefinition, error)
CollectRuntimeNodes(runtime *RuntimeNode) []*RuntimeNode
ShouldOperateOnNode(node domain.OrchestrationNode, tags []string) bool
SelectReactor(node domain.OrchestrationNode) ports.Reactor
VerifyNodeHealth(runtime *RuntimeNode, environment string) error
RunProcess(request ports.ProcessRunRequest) error
ListNodeManeuvers(node domain.OrchestrationNode) []domain.ManeuverDefinition
Info(message string, arguments ...any)
Warn(message string, arguments ...any)
Success(message string, arguments ...any)
}
Engine defines orchestration internals required by actions.
type OperationOptions ¶
OperationOptions controls one orchestration capability call.
type RuntimeNode ¶
type RuntimeNode struct {
Node domain.OrchestrationNode
LocalID string
Binary string
Children []*RuntimeNode
HealthCheck *domain.HealthCheckDefinition
}
RuntimeNode stores resolved orchestration state for one node.